@@ -44,16 +44,16 @@ from repliclust.utils import sample_unit_vectors
 # names and default parameters of supported probability distribution
 SUPPORTED_DISTRIBUTIONS = {
     'normal': {},
-    'standard_t': {'df': 1},
+    'standard_t': {'df': 5},
     'exponential': {},
-    'beta': {'a': 0.3, 'b': 0.5},
-    'chisquare': {'df': 1},
-    'gumbel': {'scale': 1.0},
-    'weibull': {'a': 2},
-    'gamma': {'shape': 0.5, 'scale': 1.0},
-    'pareto': {'a': 1},
-    'f': {'dfnum': 1, 'dfden': 1},
-    'lognormal': {'sigma': 1.0},
+    'beta': {'a': 2.5, 'b': 8.5},
+    'chisquare': {'df': 5},
+    'gumbel': {},
+    'weibull': {'a': 1.5},
+    'gamma': {'shape': 3},
+    'pareto': {'a': 10},
+    'f': {'dfnum': 7, 'dfden': 10},
+    'lognormal': {'sigma': 0.75},
 }
 
 
@@ -250,7 +250,7 @@ class SingleClusterDistribution():
     def __init__(self, **params):
         self.params = params
 
-    def _sample_1d(self, n, **params):
+    def _sample_1d(self, n, dim):
         """ 
         Sample one-dimensional data.
 
@@ -261,6 +261,8 @@ class SingleClusterDistribution():
         ----------
         n : int
             The number of samples to generate.
+        dim : int
+            The number of dimensions of the cluster.
 
         Returns
         -------
@@ -300,7 +302,7 @@ class SingleClusterDistribution():
                     + ' vectors; axes must be square matrix.')
         dim = axes.shape[1]
         directions = sample_unit_vectors(n, dim)
-        scaling = self._sample_1d(n)
+        scaling = self._sample_1d(n, dim)
         return (center[np.newaxis,:]
                 + ((directions * scaling[:,np.newaxis])
                     @ np.diag(axis_lengths)
@@ -474,7 +476,8 @@ class Archetype():
 
     See also
     --------
-    :py:class:`MaxMinArchetype <repliclust.maxmin.archetype.MaxMinArchetype>`
+    :py:class:`MaxMinArchetype <repliclust.maxmin.archetype.MaxMinArchetype>` :
+        The default implementation for a dataset archetype.
 
     """
 
@@ -494,7 +497,7 @@ class Archetype():
         
         self.n_clusters = int(n_clusters)
         self.dim = dim
-        self.n_samples = n_samples
+        self.n_samples = int(n_samples)
         self.name = name
         self.scale = scale
 
@@ -506,7 +509,7 @@ class Archetype():
         for key, val in kwargs.items():
             setattr(self, key, val)
     
-    def sample_mixture_model(self):
+    def sample_mixture_model(self, quiet=False):
         """
         Sample a probabilistic mixture model according to this 
         archetype.
@@ -528,7 +531,9 @@ class Archetype():
             self.covariance_sampler.sample_covariances(self)
         if self.n_clusters >= 2:
             self._centers = (self.center_sampler
-                                .sample_cluster_centers(self))
+                                .sample_cluster_centers(
+                                    self,
+                                    quiet=quiet))
         elif self.n_clusters == 1:
             self._centers = np.zeros(self.dim)[np.newaxis,:]
         else:
@@ -565,15 +570,15 @@ class DataGenerator():
     a DataGenerator. After constructing a DataGenerator `dg`, you can 
     write:
 
-    1) ``X, y, archetype_name = dg.synthesize(n_samples)``
+    1) ``X, y, archetype = dg.synthesize(n_samples)``
         Generate a single data set with the desired number of samples.
 
-    2) ``for X, y, archetype_name in dg: ...``                        
+    2) ``for X, y, archetype in dg: ...``                        
         Iterate over `dg` and generate `dg._n_datasets` datasets, each 
         with the number of samples specified by the corresponding 
         archetype.
 
-    3) ``for X, y, archetype_name in dg(n_datasets, n_samples): ...``
+    3) ``for X, y, archetype in dg(n_datasets, n_samples): ...``
         Iterate over `dg` and generate `n_datasets` datasets, each with
         `n_samples` data points if `n_samples` is a number; if
         `n_samples` is a list of n_datasets numbers, the i-th dataset 
@@ -585,8 +590,8 @@ class DataGenerator():
     :py:class:`ndarray <numpy.ndarray>` containing the data points 
     (samples by variables) and y is a vector-shaped :py:class:`ndarray \
     <numpy.ndarray>` containing the cluster labels. 
-    Finally, `archetype_name` is the name of the archetype used to
-    construct the dataset.
+    Finally, `archetype` is the data set archetype from which the data
+    set was generated.
 
 
     Parameters
@@ -598,7 +603,7 @@ class DataGenerator():
     """
 
     def __init__(self, archetype, n_datasets=10, 
-                 prefix='archetype'):
+                 quiet=False, prefix='archetype'):
         """
         Instantiate a DataGenerator object.
         """
@@ -620,6 +625,7 @@ class DataGenerator():
                                 + ' values are archetypes.')
         self._next_archetype_idx = 0
         self._n_datasets = n_datasets
+        self._quiet = quiet
 
 
     def __iter__(self):
@@ -633,21 +639,26 @@ class DataGenerator():
         """
         Fetch the next data set from this data generator.
         """
+        quiet = self._quiet
+
         if self._iter_count >= self._n_datasets:
             raise StopIteration
 
-        bp_name, bp = self._archetypes[self._next_archetype_idx]
-        group_sizes = (bp.groupsize_sampler
-                         .sample_group_sizes(bp, bp.n_samples))
-        X, y = bp.sample_mixture_model().sample_data(group_sizes) 
+        arch_name, arch = self._archetypes[self._next_archetype_idx]
+        group_sizes = (arch.groupsize_sampler
+                         .sample_group_sizes(arch, arch.n_samples))
+        X, y = (arch.sample_mixture_model(quiet=quiet)
+                    .sample_data(group_sizes))
 
         self._next_archetype_idx = ((self._next_archetype_idx + 1) %
                                         len(self._archetypes))
         self._iter_count += 1
-        return (X, y, bp_name)
+        arch.name = arch_name # make sure the archetype stores its name
+        return (X, y, arch)
 
 
-    def __call__(self, n_datasets=None, n_samples=None):
+    def __call__(self, n_datasets=None, n_samples=None, 
+                 quiet=False):
         """
         Set up a generator to yield `n_datasets` data sets, where 
         `n_samples` determines the number of samples in each dataset.
@@ -664,16 +675,20 @@ class DataGenerator():
             dataset will consist of n_samples[i] data points. If
             n_samples is not specified, use the value specified by
             each archetype instead.
+        quiet : bool
+            If true, suppress all print output.
 
         Yields
         ------
-        (X, y, archetype_name) : tuple[ :py:class:`ndarray \
-            <numpy.ndarray>`, :py:class:`ndarray <numpy.ndarray>`, str]
+        (X, y, archetype) : tuple[:py:class:`ndarray \
+            <numpy.ndarray>`, :py:class:`ndarray <numpy.ndarray>`, \
+                :py:class:`Archetype <repliclust.base.Archetype>`]
             Tuple with three components. The first component, `X`, 
             stores the new data set as a matrix (each row is a data
             point). The second component, `y`, stores the cluster labels
             (`y[i]` is the label of data point `X[i,:]`). The third
-            component, `arch_name`, is the name of the archetype used to create `X`, `y`.
+            component, `archetype`, is the data set archetype that
+            was used to create `X` and `y`.
         """
         if not n_datasets:
             n_datasets = self._n_datasets
@@ -694,16 +709,19 @@ class DataGenerator():
 
 
         for i in range(n_datasets):
-            bp_name, bp = self._archetypes[i % len(self._archetypes)]
-            group_sizes = (bp.groupsize_sampler
+            arch_name, arch = self._archetypes[i % len(self._archetypes)]
+            group_sizes = (arch.groupsize_sampler
                              .sample_group_sizes(
-                                bp, 
+                                arch, 
                                 _n_samples[i % len(_n_samples)]))
-            X, y = bp.sample_mixture_model().sample_data(group_sizes)
-            yield (X, y, bp_name)
+            X, y = (arch.sample_mixture_model(
+                            quiet=quiet)
+                        .sample_data(group_sizes))
+            arch.name = arch_name # make sure archetype stores its name
+            yield (X, y, arch)
 
 
-    def synthesize(self, n_samples=None):
+    def synthesize(self, n_samples=None, quiet=False):
         """
         Synthesize a data set according to the specified archetype(s).
         If this data generator consists of more than one archetype, this
@@ -715,33 +733,41 @@ class DataGenerator():
             Desired total number of data points to sample. Optional.
             If specified, overrides the number of samples specified
             by an archetype object.
+        quiet : bool
+            If true, suppress all print output. This option is useful
+            when placing many successive calls to `synthesize`.
 
         Returns
         -------
-        (X, y, archetype_name) : tuple[:py:class:`ndarray \
-            <numpy.ndarray>`, :py:class:`ndarray <numpy.ndarray>`, str]
+        (X, y, archetype) : tuple[:py:class:`ndarray \
+            <numpy.ndarray>`, :py:class:`ndarray <numpy.ndarray>`, \
+                :py:class:`Archetype <repliclust.base.Archetype>`]
             Tuple with three components. The first component, `X`, 
             stores the new data set as a matrix (each row is a data
             point). The second component, `y`, stores the cluster labels
             (`y[i]` is the label of data point `X[i,:]`). The third
-            component, `arch_name`, is the name of the archetype that
-            was used to create `X`, `y`.
+            component, `archetype`, is the data set archetype that
+            was used to create `X` and `y`.
         """
         arch_name, arch = self._archetypes[self._next_archetype_idx]
         group_sizes = (arch.groupsize_sampler
                          .sample_group_sizes(
                             arch, 
                             n_samples if n_samples else arch.n_samples))
-        X, y = arch.sample_mixture_model().sample_data(group_sizes)
+        X, y = (arch.sample_mixture_model(quiet=quiet)
+                    .sample_data(group_sizes))
         # increment the index for the next archetype
         self._next_archetype_idx = ((self._next_archetype_idx + 1) %
                                         len(self._archetypes))
-        return (X, y, arch_name)
+        arch.name = arch_name # make sure archetype stores its name
+        return (X, y, arch)
 
     def __repr__(self):
         """
         Construct string representation of this DataGenerator.
         """
         return ("DataGenerator" 
-                    + "\n\t- archetype(s) : " + str(1)
-                    + "\n\t- n_datasets (default) : " + str(2))
\ No newline at end of file
+                    + "\n\t- archetype(s) : "
+                    + str(len(self._archetypes))
+                    + "\n\t- n_datasets : "
+                    + str(self._n_datasets))
\ No newline at end of file
